slepc-3.18.0 2022-10-01
Report Typos and Errors

# DSCond

Compute the condition number.

### Synopsis

    #include "slepcds.h"
    PetscErrorCode DSCond(DS ds,PetscReal *cond)

Not Collective

### Input Parameters

| ds | - the direct solver context
| cond | - the computed condition number

### Notes

In standard eigenvalue problems, returns the inf-norm condition number of the first matrix, computed as cond(A) = norm(A)*norm(inv(A)).

In GSVD problems, returns the maximum of cond(A) and cond(B), where cond(.) is computed as the ratio of the largest and smallest singular values.

Does not take into account the extra row.

### See Also

DSSolve(), DSSetExtraRow()

### Level

advanced

### Location

src/sys/classes/ds/interface/dsops.c
Index of all DS routines
Table of Contents for all manual pages
Index of all manual pages